@@ -23,7 +23,13 @@ For more fine-grained access, use:
    dev
 
 """
-__version__ = "0.5.0"
+__version__ = "0.5.2"
+
+# init jupyter lab frontend immediately on import
+# nothing happens if this is not jupyter lab
+from .dev._jupyter_lab_commands import _init_frontend
+
+_init_frontend()
 
 from . import dev
 from ._header import header
