@@ -4,7 +4,7 @@ from typing import List, Mapping, Optional, Union
 from pydantic import BaseModel, Extra
 
 from .._logger import logger
-from ._jupyter_lab_commands import _reload_notebook, _save_notebook
+from ._frontend_commands import _reload_notebook, _save_notebook
 from ._metadata_display import table_metadata
 from ._notebook import Notebook, read_notebook, write_notebook
 from ._pypackage import _get_version
@@ -111,8 +111,8 @@ class MetaStore:
 
         Outside Jupyter Lab: Save the notebook before writing.
         """
-        if self._env == "lab":
-            _save_notebook()
+        if self._env in ("lab", "notebook"):
+            _save_notebook(self._env)
 
         nb = read_notebook(self._filepath)
 
@@ -126,8 +126,8 @@ class MetaStore:
 
         write_notebook(nb, self._filepath)
 
-        if self._env == "lab":
-            _reload_notebook()
+        if self._env in ("lab", "notebook"):
+            _reload_notebook(self._env)
         elif self._env != "test":
             logger.info(
                 "File changed on disk! Reload the notebook if you want to continue."
